Learn R Programming

BayesFluxR (version 0.1.3)

BayesFluxR_setup: Set up of the Julia environment needed for BayesFlux

Description

This will set up a new Julia environment in the current working directory or another folder if provided. This environment will then be set with all Julia dependencies needed.

Usage

BayesFluxR_setup(
  pkg_check = TRUE,
  nthreads = 4,
  seed = NULL,
  env_path = getwd(),
  installJulia = FALSE,
  ...
)

Value

No return value, called for side effects.

Arguments

pkg_check

(Default=TRUE) Check whether needed Julia packages are installed

nthreads

(Default=4) How many threads to make available to Julia

seed

Seed to be used.

env_path

The path to were the Julia environment should be created. By default, this is the current working directory.

installJulia

(Default=TRUE) Whether to install Julia

...

Other parameters passed on to julia_setup

Examples

Run this code
if (FALSE) {
  ## Time consuming and requires Julia and BayesFlux.jl
  BayesFluxR_setup(installJulia=TRUE, seed=123)
}

Run the code above in your browser using DataLab