BayesFluxR_setup: Set up of the Julia environment needed for BayesFlux
Description
This will set up a new Julia environment in the current working
directory or another folder if provided. This environment will
then be set with all Julia dependencies needed.